agentle.agents.whatsapp.models.data
===================================

.. automodule:: agentle.agents.whatsapp.models.data

   
   .. rubric:: Functions

   .. autosummary::
   
      TypedDict
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      Data
      Key
      Message
   